@@ -1,13 +1,10 @@
 """The PyWENO module."""
 
+import points
 import kernels
 import nonuniform
 import symbolic
 import symbols
 import version
 import weno
-
-# import points
-# import nonuniform_codegen
-
 import cweno
